var structnl__dump__params =
[
    [ "dp_type", "structnl__dump__params.html#ae36d840078202bf028a6611d2e1f4ea5", null ],
    [ "dp_prefix", "structnl__dump__params.html#a6fd1500e450689a268d89b1ee20311cc", null ],
    [ "dp_print_index", "structnl__dump__params.html#a4a3f61556916405f8b4f73d6beb7e7b4", null ],
    [ "dp_dump_msgtype", "structnl__dump__params.html#a8935db5205e6d5967402784e59895690", null ],
    [ "dp_cb", "structnl__dump__params.html#a5e5df54fe249a13838b08225cfeea651", null ],
    [ "dp_nl_cb", "structnl__dump__params.html#aff4ba55e34dc59c3e56fb5538f932f35", null ],
    [ "dp_data", "structnl__dump__params.html#a4531c95c193d75b25a22ced77b3e3ba8", null ],
    [ "dp_fd", "structnl__dump__params.html#afe6d9b7154f8f6a4fa9469e859f1f652", null ],
    [ "dp_buf", "structnl__dump__params.html#ad069c751442fcf74c9f1bf25f0f5af92", null ],
    [ "dp_buflen", "structnl__dump__params.html#a63a511bbc4d12484ada704dcfc0818c0", null ],
    [ "dp_pre_dump", "structnl__dump__params.html#a08aa2ae4636d506c7b4ccf26f37ee605", null ],
    [ "dp_ivar", "structnl__dump__params.html#af1f8a5423568e809b67080908eecf6aa", null ]
];